Bitnomon Testing

## Manual Tests

- Basic connectivity (covers loading bitcoin.conf)
- All menu items
- Window resizing
- Status bar
- Age axis zooming
- Mempool plot panning fluidity
- Generation of bitcoin.conf, with properly restricted permissions
- Run over 10 mins to check traffic average displays and RRD, and restart
- Saving of window size, position, status bar, network units across restart
- Full screen menu bar hiding, keyboard shortcuts, and WM sync
- pyqtgraph mouse controls: left click panning, right click zooming, scroll wheel zooming, all of the above constrained to an axis, lower-left auto-zoom button, context menu
- Graceful close on SIGINT (albeit up to 2 second delay)
- Memory usage over 24 hours
- Package build/installation; desktop icon
- No unhandled exceptions
- -testnet, -debug